@@ -100,40 +100,14 @@ EicielContainer::EicielContainer()
 
 void EicielContainer::mostrarAjuda()
 {
-	// Farem com fa l'ajuda de GNOME pero sense usar
-	// tota la cutreria de GNOME
-	
-	// Obtenim la llista de llenguatges. Aix incorporar C en el
-	// pitjor dels casos
-	const GList *lang_list = gnome_i18n_get_language_list ("LC_MESSAGES");
-	Glib::FileTest ftest = Glib::FILE_TEST_EXISTS;
+    GError* error = NULL;
 
-	for (;lang_list != NULL; lang_list = lang_list->next)
-	{
-		// const char *lang = lang_list->data;
-		// Glib::ustring cami_ajuda(lang_list->data);
-
-		// Ho fem comode pero ineficient xD
-		Glib::ustring cami_ajuda = Glib::ustring(PKGDATADIR "/doc/") +
-			Glib::ustring((const char*)lang_list->data) + 
-			Glib::ustring("/eiciel.xml");
-
-		Glib::ustring uri_ajuda = Glib::ustring("ghelp:") + cami_ajuda;
-
-		if (Glib::file_test(cami_ajuda, ftest))
-		{
-			if (!gnome_help_display_uri(uri_ajuda.c_str(), NULL))
-			{
-				g_warning(_("Could not show the help file even if it was found"));
-			}
-			// else
-			// {
-			// 	g_warning("Hem obert %s", uri_ajuda.c_str());
-			// }
-			return;
-		}
-	}
-	g_warning(_("Help file not found"));
+    gnome_help_display("eiciel", NULL, &error);
+    if (error != NULL)
+    {
+        g_warning(_("Could not show the help file: %s"), error->message);
+        g_error_free(error);
+    }
 }
 
 void EicielContainer::sortidaAplicacio()
