@@ -113,7 +113,7 @@ EicielWindow::EicielWindow(EicielMainControler* cont)
 	contenidorVistaLlistaACL.add(vistaLlistaACL);
 	contenidorVistaLlistaACL.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
 
-	vistaLlistaACL.set_size_request(-1, 150);
+	vistaLlistaACL.set_size_request(100, 150);
 
 	zona_superior.add(contenidorVistaLlistaACL);
 
@@ -322,7 +322,10 @@ void EicielWindow::activacio(bool b)
 void EicielWindow::establirNomesLectura(bool b)
 {
 	modeNomesLectura = b;
-	modificarACLDefault.set_sensitive(!b);
+	if (b)
+	{
+		modificarACLDefault.set_sensitive(false);
+	}
 	zona_inferior.set_sensitive(!b);
 }
 
@@ -427,7 +430,7 @@ void EicielWindow::afegeixNoSeleccionable(Glib::ustring titol,
 {
 	Gtk::TreeModel::iterator iter = refLlistaACL->append();
 	Gtk::TreeModel::Row row(*iter);
-	row = *iter;
+
 	afegeixElement(titol, lectura, escriptura, execucio, e, row, 
 			efectiuLectura, efectiuEscriptura, efectiuExecucio);
 	row[modelLlistaACL.esborrable] = false;
