@@ -16,24 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include "config.hpp"
-#include <glibmm.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/acl.h>
-#ifdef HAVE_ACL_LIBACL_H
- #include <acl/libacl.h>
-#endif
-#include <unistd.h>
-#include <errno.h>
-#include <vector>
-#include <iostream>
-#include <pwd.h>
-#include <grp.h>
-#include <sstream>
-#include <algorithm>
 #include "gestor_acl.hpp"
-#include <gettext.h>
 
 GestorACL::GestorACL(const string& nomF) throw (GestorACLException)
 	: nomFitxer(nomF) 
